function ModelParameters = InitializeSWFFParameters(ModelParameters)
% InitializeSWFFParameters: Shows how to define calibrated parameters for the Del Negro and Schorfheide
%                           variant of the Smets and Wouters model with BGG-type financial frictions.
%
% USAGE:
%
%       ModelParameters = InitializeSWFFParameters(ModelParameters)
%
% REQUIRED INPUT:  ModelParameters (structure) with fields corresponding to the parameters
%                                   you need for defining new parameters that should be
%                                   added to the structure.
%
% REQUIRED OUTPUT: ModelParameters (structure) with additions to the input structure.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/MPR
%                                   European Central Bank
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2015 European Central Bank.
%
%                       First version: February 12, 2014.
%                        This version: May 22, 2015.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 13-02-2014: Updated the documentation.
%
% * 13-01-2015: Updated the documentation.
%
% * 22-05-2015: Prepared the file for use with euro area data.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% Fixed parameters in Del Negro and Schorfheide (2013, Handbook of Economic Forecasting)
%
ModelParameters.delta = 0.025;
ModelParameters.phiw = 1.5;
ModelParameters.gy = 0.18;
ModelParameters.epsilonp = 10;
ModelParameters.epsilonw = 10;
ModelParameters.fbar = 0.0075;
ModelParameters.kappae = 0.99;

%
% end of InitializeSWFFParameters.m
%
