function ModelParameters = InitializeSWUParameters(ModelParameters)
% InitializeGSWParameters: Shows how to define calibrated parameters from possibly previously defined parameters
%
% USAGE:
%
%       ModelParameters = InitializeSWUParameters(ModelParameters)
%
% REQUIRED INPUT:  ModelParameters (structure) with fields corresponding to the parameters
%                                   you need for defining new parameters that should be
%                                   added to the structure.
%
% REQUIRED OUTPUT: ModelParameters (structure) with additions to the input structure.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/EMO
%                                   European Central Bank
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2015 European Central Bank.
%
%                       First version: August 19, 2011.
%                        This version: May 7, 2015.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 29-04-2015: Changed the name of the function for the McAdam-Warne exercises.
%
% * 30-04-2015: Added the MA parameters from the price and wage markup shocks.
%
% * 07-05-2015: Added rhos as a potential calibrated parameter.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% Fixed parameters in Smets, Warne and Wouters (2011)
%

%ModelParameters.mup = 0;
%ModelParameters.muw = 0;
if isfield(ModelParameters,'rhos')==0;
   ModelParameters.rhos = 0.999;
end;
if isfield(ModelParameters,'sigmac')==0;
   ModelParameters.sigmac = 1;
end;
ModelParameters.delta = 0.025;
ModelParameters.gy = 0.18;
ModelParameters.epsilonp = 10;

%
% end of InitializeSWUParameters.m
%
